==> BOP-1.9-4.0.x.zip: biomesoplenty/src/main/java/biomesoplenty/api/item/BOPItems.java <==
/*******************************************************************************
 * Copyright 2014-2016, the Biomes O' Plenty Team
 * 
 * This work is licensed under a Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International Public License.
 * 
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-nd/4.0/.
 ******************************************************************************/

package biomesoplenty.api.item;

import net.minecraft.item.Item;

public class BOPItems
{
    
    public static Item berries;
    public static Item shroompowder;
    public static Item peach;
    public static Item saladfruit;
    public static Item saladveggie;
    public static Item saladshroom;
    public static Item earth;
    public static Item persimmon;
    public static Item filled_honeycomb;
    public static Item ambrosia;
    public static Item turnip;
    public static Item pear;
    public static Item ricebowl;
    
    public static Item fleshchunk;
    public static Item mudball;
    public static Item turnip_seeds;
    public static Item crystal_shard;
    public static Item terrestrial_artifact;
    public static Item flax_string;
    public static Item honeycomb;
    public static Item gem;
    public static Item ash;
    public static Item mud_brick;
    public static Item blue_dye;
    public static Item brown_dye;
    public static Item green_dye;
    public static Item white_dye;
    public static Item black_dye;
    public static Item soul;
    public static Item pixie_dust;
    public static Item ichor;
    public static Item pinecone;
    public static Item other_slab;
    
    public static Item dart;
    public static Item dart_blower;
    
    public static Item sacred_oak_door;
    public static Item cherry_door;
    public static Item umbran_door;
    public static Item fir_door;
    public static Item ethereal_door;
    public static Item magic_door;
    public static Item mangrove_door;
    public static Item palm_door;
    public static Item redwood_door;
    public static Item willow_door;
    public static Item pine_door;
    public static Item hellbark_door;
    public static Item jacaranda_door;
    public static Item mahogany_door;
    public static Item ebony_door;
    public static Item eucalyptus_door;
    
    public static Item wood_slab_0;
    public static Item wood_slab_1;
    
    public static Item wading_boots;
    public static Item flippers;
    public static Item plain_flower_band;
    public static Item lush_flower_band;
    public static Item exotic_flower_band;
    public static Item dull_flower_band;
    
    public static Item mud_helmet;
    public static Item mud_chestplate;
    public static Item mud_leggings;
    public static Item mud_boots;
    public static Item amethyst_helmet;
    public static Item amethyst_chestplate;
    public static Item amethyst_leggings;
    public static Item amethyst_boots;
    
    public static Item mud_axe;
    public static Item mud_hoe;
    public static Item mud_pickaxe;
    public static Item mud_shovel;
    public static Item mud_sword;
    public static Item amethyst_axe;
    public static Item amethyst_hoe;
    public static Item amethyst_pickaxe;
    public static Item amethyst_shovel;
    public static Item amethyst_sword;
    
    public static Item mud_scythe;
    public static Item wood_scythe;
    public static Item stone_scythe;
    public static Item iron_scythe;
    public static Item gold_scythe;
    public static Item diamond_scythe;
    public static Item amethyst_scythe;
    
    public static Item biome_finder;
    public static Item biome_essence;
    public static Item enderporter;
    public static Item flower_basket;
    public static Item jar_empty;
    public static Item jar_filled;
    public static Item honey_bucket;
    public static Item blood_bucket;
    public static Item poison_bucket;
    public static Item hot_spring_water_bucket;
    
    public static Item record_wanderer;
    public static Item record_corruption;
    
    public static Item spawn_egg;
    
    // TODO: public static Item ancientStaff;
    // TODO: public static Item bop_bucket;
    
    
}

==> BOP-1.9.4-4.1.x.zip: biomesoplenty/src/main/java/biomesoplenty/api/item/BOPItems.java <==
/*******************************************************************************
 * Copyright 2014-2016, the Biomes O' Plenty Team
 * 
 * This work is licensed under a Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International Public License.
 * 
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-nd/4.0/.
 ******************************************************************************/

package biomesoplenty.api.item;

import net.minecraft.item.Item;

public class BOPItems
{
    
    public static Item berries;
    public static Item shroompowder;
    public static Item peach;
    public static Item saladfruit;
    public static Item saladveggie;
    public static Item saladshroom;
    public static Item earth;
    public static Item persimmon;
    public static Item filled_honeycomb;
    public static Item ambrosia;
    public static Item turnip;
    public static Item pear;
    public static Item ricebowl;
    
    public static Item fleshchunk;
    public static Item mudball;
    public static Item turnip_seeds;
    public static Item crystal_shard;
    public static Item terrestrial_artifact;
    public static Item flax_string;
    public static Item honeycomb;
    public static Item gem;
    public static Item ash;
    public static Item mud_brick;
    public static Item blue_dye;
    public static Item brown_dye;
    public static Item green_dye;
    public static Item white_dye;
    public static Item black_dye;
    public static Item soul;
    public static Item pixie_dust;
    public static Item ichor;
    public static Item pinecone;
    public static Item other_slab;
    
    public static Item sacred_oak_door;
    public static Item cherry_door;
    public static Item umbran_door;
    public static Item fir_door;
    public static Item ethereal_door;
    public static Item magic_door;
    public static Item mangrove_door;
    public static Item palm_door;
    public static Item redwood_door;
    public static Item willow_door;
    public static Item pine_door;
    public static Item hellbark_door;
    public static Item jacaranda_door;
    public static Item mahogany_door;
    public static Item ebony_door;
    public static Item eucalyptus_door;
    
    public static Item wood_slab_0;
    public static Item wood_slab_1;
    
    public static Item wading_boots;
    public static Item flippers;
    public static Item plain_flower_band;
    public static Item lush_flower_band;
    public static Item exotic_flower_band;
    public static Item dull_flower_band;
    
    public static Item mud_helmet;
    public static Item mud_chestplate;
    public static Item mud_leggings;
    public static Item mud_boots;
    
    public static Item mud_axe;
    public static Item mud_hoe;
    public static Item mud_pickaxe;
    public static Item mud_shovel;
    public static Item mud_sword;
    
    public static Item mud_scythe;
    public static Item wood_scythe;
    public static Item stone_scythe;
    public static Item iron_scythe;
    public static Item gold_scythe;
    public static Item diamond_scythe;
    
    public static Item biome_finder;
    public static Item biome_essence;
    public static Item enderporter;
    public static Item flower_basket;
    public static Item jar_empty;
    public static Item jar_filled;
    public static Item sand_bucket;
    public static Item honey_bucket;
    public static Item blood_bucket;
    public static Item poison_bucket;
    public static Item hot_spring_water_bucket;
    
    public static Item record_wanderer;
    public static Item record_corruption;
    
    public static Item spawn_egg;
    
    // TODO: public static Item ancientStaff;
    // TODO: public static Item bop_bucket;
    
    
}
